//
// Copyright (c) 2019 The University of Aizu
// Open source under the BSD License.
//

// Native
const { join } = require('path')
const { format } = require('url')

// Packages
const { BrowserWindow, app, ipcMain } = require('electron');
// const ipc = require('ipc');
const isDev = require('electron-is-dev');
const prepareNext = require('electron-next');

const isProd = process.env.NODE_ENV === 'production';

const {
  default: installExtension,
  REACT_DEVELOPER_TOOLS,
  REDUX_DEVTOOLS,
  APOLLO_DEVELOPER_TOOLS } = require('electron-devtools-installer');

// Prepare the renderer once the app is ready
app.on('ready', async () => {
  await prepareNext('./renderer');

  const mainWindow = new BrowserWindow({
    width: 1440,
    height: 900,
    minWidth: 1440,
    minHeight: 900,
    show: false,
    useContentSize: true,
    webPreferences: {
      // webSecurity: false,
      nodeIntegration: false,
      preload: join(__dirname, 'preload.js')
    }
  });

  const main_url = isDev
    ? 'http://localhost:8000/'
    : format({
      pathname: join(__dirname, '../renderer/index.html'),
      protocol: 'file:',
      slashes: true
    });

  mainWindow.once('ready-to-show', () => {
    mainWindow.show();
    mainWindow.webContents.send('message', __dirname);
  });

  mainWindow.loadURL(main_url);

  // DevTools
  installExtension(REACT_DEVELOPER_TOOLS);
  installExtension(REDUX_DEVTOOLS);
  mainWindow.webContents.openDevTools();


  // console.log("cwd", process.cwd());
  // console.log("__dirname", __dirname);
  // mainWindow.webContents.send('message', __dirname);


  // ipcMain.on('message', (event, message) => {
  //
  //   // Communicate asynchronously from the main process to renderer processes.
  //   mainWindow.webContents.send('message', message);
  //
  // });
})

// Quit the app once all windows are closed
app.on('window-all-closed', app.quit);
