{/*
// Copyright (c) 2019 The University of Aizu
// Open source under the BSD License.
*/}

// React Library
import { useState, useEffect } from 'react';
import { connect } from 'react-redux';
import { string } from 'prop-types';
import axios from 'axios';
import { gql }  from 'apollo-boost';

// Modules
import { setToken } from '../modules/token';
import { setPath } from '../modules/path';

// Helpers
import client from '../helpers/client';



const Holder = ({ label, setToken }) => {

  const [values, setValues] = useState({user_id: '', password: ''});  // TODO: user_id, password

  function handleSignin () {
    axios.post(process.env.REACT_APP_TOKEN_URL, {
      user_id: values.user_id,
      password: values.password,
    }).then(response => {
      console.log(global.ipcRenderer);

      setToken(response.data.access_token);
      setValues({...values, user_id: '', password: ''});
    }).catch(error => {
      console.error(`Can't do because: ${error}`);
    });
  }

  function handleInputChange (e) {
    let { name, value } = e.target;
    setValues({...values, [name]: value});
  }

  return (
    <div className="u-holder">
      <h1 className="holder-title ttl-lg">{ label }</h1>
      <label className="holder-field">
        <div className="holder-label">User ID:</div>
        <input
          type="text"
          name="user_id"
          value={values.user_id}
          id="user_id"
          className="holder-input input-primary"
          onChange={ handleInputChange } />
      </label>
      <label className="holder-field">
        <div className="holder-label">Password:</div>
        <input
          type="password"
          name="password"
          value={ values.password }
          id="password"
          className="holder-input input-primary"
          onChange={ handleInputChange } />
      </label>
      <button type="button" className="holder-button btn-outline" onClick={ handleSignin }>Sign in</button>
    </div>
  );
};

const mapDispatchToProps = dispatch => ({
  setToken: token => dispatch(setToken(token)),
  setPath: token => dispatch(setPath(path)),
});

const mapStateToProps = state => ({
  token_data: state.tokenReducer.token_data,
  path_data: state.pathReducer.path_data,
});

Holder.propTypes = {
  token_data: string,
  path_data: string,
};

export default connect(mapStateToProps, mapDispatchToProps)(Holder);
