//
// Copyright (c) 2019 The University of Aizu
// Open source under the BSD License.
//

// React Library
import React, { useEffect, useState } from 'react';
import { connect } from 'react-redux';
import { string } from 'prop-types';

// Apollo
import ApolloClient, { InMemoryCache, gql }  from 'apollo-boost';
import { Query, withApollo, compose } from 'react-apollo';

// Components
import InputSearch    from '../components/InputSearch';
import RadioButton    from '../components/RadioButton';
import CheckboxButton from '../components/CheckboxButton';
import SelectPrimary  from '../components/SelectPrimary';
import Widget         from '../components/Widget';
import Chip           from '../components/Chip';
import Toolbar        from '../components/Toolbar';
import Panel          from '../components/Panel';
import Overlay        from '../components/Overlay';

import { setPath } from '../modules/path';

const QUERY_TYPE = gql`
  query fetchTypeMany {
    typeMany {
      _id
      name
    }
  }
`;

const QUERY_FACE = gql`
  query fetchFaceMany {
    faceMany {
      _id
      name
    }
  }
`;

const QUERY_PANEL = gql`
  query fetchPanelMany {
    panelMany {
      _id
      name
    }
  }
`;

const QUERY_SUBTEAM = gql`
  query fetchSubTeamMany {
    subTeamMany {
      _id
      name
    }
  }
`;

const QUERY_SIZE = gql`
  query fetchSizeMany {
    sizeMany {
      _id
      name
    }
  }
`;

const QUERY_IMPACTDATA = gql`
  query getImpactDataMany(
    $panel: PanelInput,
    $sub_team: SubTeamInput,
    $face: ImpactDataFaceInput,
    $size1: [ImpactDataSizeInput],
    $size2: [ImpactDataSizeInput],
    $size3: [ImpactDataSizeInput],
    $size4: [ImpactDataSizeInput],
    $size5: [ImpactDataSizeInput],
    $size6: [ImpactDataSizeInput],
    $type1: [TypeInput],
    $type2: [TypeInput],
    $type3: [TypeInput],
    $type4: [TypeInput],
    $type5: [TypeInput],
    $type6: [TypeInput],
    $type7: [TypeInput],
  ) {
    impactDataMany(
      filter: {AND: [
        {panel: $panel},
        {sub_team: $sub_team},
        {face: $face},
        {OR: [
          {size: $size1},
          {size: $size2},
          {size: $size3},
          {size: $size4},
          {size: $size5},
          {size: $size6}
        ]},
        {OR: [
          {type: $type1},
          {type: $type2},
          {type: $type3},
          {type: $type4},
          {type: $type5},
          {type: $type6},
          {type: $type7},
        ]}
      ]}
    ) {
      impact_id
      _id
      panel {
        name
      }
      size {
        name
      }
      face {
        name
      }
      type {
        name
      }
      sub_team {
        name
      }
      image_paths
      agreed_date
    }
  }
`;

const typename = {};

console.log("cwd", process.cwd());
console.log("__dirname", __dirname);


// console.log('global.ipcRenderer', global.ipcRenderer);
// global.ipcRenderer.send('message', 'aaaaaaaaa');
// console.log(global.ipcRenderer.send);
// global.ipcRenderer.send('message', 'aaaaaaaaaa');


class Index extends React.Component {

  constructor (props) {
    super(props);
    this.state = {};
    this.handleInputChange = this.handleInputChange.bind(this);

    // global.ipcRenderer.on('message', (event, token) => {
    //   console.log('aaaaaa');
    // });
    // global.ipcRenderer.send('message');

    // global.ipcRenderer.on('message', (event, value) => {
    //   console.log('====== obj');
    // });

  }

  handleInputChange (e) {
    const target = e.target;
    const value = target.value;
    const name = target.name;
    const data = target.dataset;

    if (target.type === 'checkbox') { // Input type is a checkbox.

      if (target.checked) {
        // checked.
        if (target.parentNode.parentNode.querySelectorAll('input:checked').length >= 0) {
          typename[data.typename] = target.checked;
        }
        this.state[name] = {};
        this.setState({
          [name]: {'_id':value}
        });
      } else {
        // unchecked.
        if (target.parentNode.parentNode.querySelectorAll('input:checked').length < 1) {
          delete typename[data.typename];
        }
        this.setState({
          [name]: null
        });
      }

    } else { // Other than check box.

      if (value) {
        // selected.
        typename[data.typename] = value;
        this.state[name] = {};
        this.setState({
          [name]: {'_id':value}
        });
      } else {
        // unselected.
        delete typename[data.typename];
        delete this.state[name];
        this.forceUpdate();
      }

    }
  }

  componentDidMount () {
    global.ipcRenderer.on('message', (event, path) => {
      this.props.setPath(path);
    });
  }

  render () {
    const { token_data, setPath } = this.props;

    return (
      <>
        <div className="l-container">
          <div className="u-sidebar">
            <Widget label="Impact ID">
              <InputSearch />
            </Widget>
            <Widget label="Panel">
            {
              token_data &&
              <Query query={ QUERY_PANEL } context={{ token_data }} fetchPolicy="network-only">
                {({ loading, error, data }) => {
                  if (loading) return false;
                  return <SelectPrimary data={ data.panelMany } typename="Panel" kind="panel" handle={ this.handleInputChange } />
                }}
              </Query>
            }
            </Widget>
            <Widget label="Allocated Sub-Team">
            {
              token_data &&
              <Query query={ QUERY_SUBTEAM } context={{ token_data }} fetchPolicy="network-only">
                {({ loading, error, data }) => {
                  if (loading) return false;
                  return <SelectPrimary data={ data.subTeamMany } typename="SubTeam" kind="sub_team" handle={ this.handleInputChange } />
                }}
              </Query>
            }
            </Widget>
            <Widget label="Face">
              <div className="checkbox-group">
              {
                token_data &&
                <Query query={ QUERY_FACE } context={{ token_data }} fetchPolicy="network-only">
                  {({ loading, error, data }) => {
                    if (loading) return false;
                    return <SelectPrimary data={ data.faceMany } typename="ImpactDataFace" kind="face" handle={ this.handleInputChange } />
                  }}
                </Query>
              }
              </div>
            </Widget>
            <Widget label="Size">
              <div className="checkbox-group">
              {
                token_data &&
                <Query query={ QUERY_SIZE } context={{ token_data }} fetchPolicy="network-only">
                  {({ loading, error, data }) => {
                    if (loading) return false;
                    return (
                      'sizeMany' in data && data.sizeMany.map(
                        (item, index) => <CheckboxButton label={ item.name } typename={ item.__typename } val={ item._id } kind={`size${index+1}`} key={ item._id } handle={ this.handleInputChange } />
                      )
                    )
                  }}
                </Query>
              }
              </div>
            </Widget>
            <Widget label="Type">
              <div className="checkbox-group">
              {
                token_data &&
                <Query query={ QUERY_TYPE } context={{ token_data }} fetchPolicy="network-only">
                  {({ loading, error, data }) => {
                    if (loading) return false;
                    return (
                      'typeMany' in data && data.typeMany.map(
                        (item, index) => <CheckboxButton label={ item.name } typename={ item.__typename } val={ item._id } kind={`type${index+1}`} key={ item._id } handle={ this.handleInputChange } />
                      )
                    );
                  }}
                </Query>
              }
              </div>
            </Widget>
          </div>
          <main className="l-main">
            <h1 className="ttl-lg">Aerogels - Initial Sample Analysis and Curation Results</h1>
            <Toolbar />
            {
              (() => {
                // let options = {};

                // if ('_id' in this.state.panel) {
                //   if (this.state.panel._id) {
                //     options.panel = this.state.panel;
                //   } else {
                //     delete options.panel;
                //   }
                // }
                //
                // if ('_id' in this.state.sub_team) {
                //   if (this.state.sub_team._id) {
                //     options.sub_team = this.state.sub_team;
                //   } else {
                //     delete options.sub_team;
                //   }
                // }

                // if (this.state.size.size) {
                //   let arr = [];
                //   [...this.state.size].forEach(value => arr.push(value[1]));
                //   options.size = arr;
                // } else {
                //   delete options.size;
                // }

                // if (this.state.face.size) {
                //   let arr = [];
                //   [...this.state.face].forEach(value => arr.push(value[1]));
                //   options.face = arr;
                // } else {
                //   delete options.face;
                // }
                //
                // if (this.state.type.size) {
                //   let arr = [];
                //   [...this.state.type].forEach(value => arr.push(value[1]));
                //   options.type = arr;
                // } else {
                //   delete options.type;
                // }

                // console.log('state', this.state);
                // console.log('typename', typename);

                // let pattern = '';
                //
                // if ('Panel' in typename === true
                //   && 'SubTeam' in typename  === false
                //   && 'ImpactDataSize' in typename === false
                //   && 'ImpactDataFace' in typename === false
                //   && 'Type' in typename === false) {
                //   pattern = 'panel_0_0_0_0';
                // }
                //
                // else if ('Panel' in typename === true
                //   && 'SubTeam' in typename  === true
                //   && 'ImpactDataSize' in typename === false
                //   && 'ImpactDataFace' in typename === false
                //   && 'Type' in typename === false) {
                //   pattern = 'panel_subteam_0_0_0';
                // }
                //
                // else if ('Panel' in typename === true
                //   && 'SubTeam' in typename  === true
                //   && 'ImpactDataSize' in typename === true
                //   && 'ImpactDataFace' in typename === false
                //   && 'Type' in typename === false) {
                //   pattern = 'panel_subteam_size_0_0';
                // }
                //
                // else if ('Panel' in typename === true
                //   && 'SubTeam' in typename  === true
                //   && 'ImpactDataSize' in typename === true
                //   && 'ImpactDataFace' in typename === true
                //   && 'Type' in typename === false) {
                //   pattern = 'panel_subteam_size_face_0';
                // }
                //
                // else if ('Panel' in typename === true
                //   && 'SubTeam' in typename  === true
                //   && 'ImpactDataSize' in typename === true
                //   && 'ImpactDataFace' in typename === true
                //   && 'Type' in typename === true) {
                //   pattern = 'panel_subteam_size_face_type';
                // }
                //
                // else if ('Panel' in typename === true
                //   && 'SubTeam' in typename  === false
                //   && 'ImpactDataSize' in typename === true
                //   && 'ImpactDataFace' in typename === false
                //   && 'Type' in typename === false) {
                //   pattern = 'panel_0_size_0_0';
                // }
                //
                // else if ('Panel' in typename === true
                //   && 'SubTeam' in typename  === false
                //   && 'ImpactDataSize' in typename === true
                //   && 'ImpactDataFace' in typename === true
                //   && 'Type' in typename === false) {
                //   pattern = 'panel_0_size_face_0';
                // }
                //
                // else if ('Panel' in typename === true
                //   && 'SubTeam' in typename  === false
                //   && 'ImpactDataSize' in typename === true
                //   && 'ImpactDataFace' in typename === true
                //   && 'Type' in typename === true) {
                //   pattern = 'panel_0_size_face_type';
                // }
                //
                // else if ('Panel' in typename === true
                //   && 'SubTeam' in typename  === false
                //   && 'ImpactDataSize' in typename === false
                //   && 'ImpactDataFace' in typename === true
                //   && 'Type' in typename === false) {
                //   pattern = 'panel_0_0_face_0';
                // }
                //
                // else if ('Panel' in typename === true
                //   && 'SubTeam' in typename  === true
                //   && 'ImpactDataSize' in typename === false
                //   && 'ImpactDataFace' in typename === true
                //   && 'Type' in typename === false) {
                //   pattern = 'panel_subteam_0_face_0';
                // }
                //
                // else if ('Panel' in typename === true
                //   && 'SubTeam' in typename  === true
                //   && 'ImpactDataSize' in typename === false
                //   && 'ImpactDataFace' in typename === true
                //   && 'Type' in typename === true) {
                //   pattern = 'panel_subteam_0_face_0';
                // }

                // console.log(pattern);

                // let pattern = [];
                // Object.keys(this.state).forEach(function (i) {
                //   pattern.push(i);
                // });
                // console.log(pattern.sort().join('_'));

                console.log('state', this.state);

                return <Query query={ QUERY_IMPACTDATA } context={{ token_data }} variables={ this.state }>
                  {({ loading, error, data }) => {
                    if (loading) return false;
                    console.log('impactDataMany', data);
                    return (
                      'impactDataMany' in data && data.impactDataMany.map(
                        (item, index) => {


                          return <Panel data={ item } key={ item._id } />
                        }
                      )
                    );
                  }}
                </Query>

              })()
            }
          </main>
        </div>

        <Overlay />

      </>
    );
  }
}

const mapDispatchToProps = dispatch => ({
  setPath: path => dispatch(setPath(path)),
});

const mapStateToProps = state => ({
  token_data: state.tokenReducer.token_data,
  path_data: state.pathReducer.path_data,
});

Index.propTypes = {
  token_data: string,
  path_data: string,
};

export default connect(mapStateToProps, mapDispatchToProps)(Index);
